#
# spec file for package libxfce4ui
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git

Name:           libxfce4ui
Version:        4.20.0
Release:        1.3
Summary:        Widgets Library for the Xfce Desktop Environment
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://www.xfce.org/
Source0:        https://archive.xfce.org/src/xfce/libxfce4ui/4.20/%{name}-%{version}.tar.bz2
# needed until all applications have been ported to xfce_dialog_show_help() or
# an alternative mechanism
Source1:        xfhelp4.sh
# PATCH-FIX-OPENSUSE 0001-relax-x11-version.patch -- Allow build for Leap with its ancient but sufficient X11 packages.
Patch1:         0001-relax-x11-version.patch
BuildRequires:  gettext >= 0.19.8
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gdk-wayland-3.0) >= 3.24.10
BuildRequires:  pkgconfig(gladeui-2.0) >= 3.5.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.66.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(gudev-1.0) >= 232
BuildRequires:  pkgconfig(ice) >= 1.0.9
BuildRequires:  pkgconfig(libgtop-2.0) >= 2.24.0
BuildRequires:  pkgconfig(libstartup-notification-1.0) >= 0.4
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.17.2
BuildRequires:  pkgconfig(libxfconf-0) >= 4.12.0
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(sm) >= 1.2.2
BuildRequires:  pkgconfig(vapigen)
BuildRequires:  pkgconfig(wayland-client) >= 1.20
BuildRequires:  pkgconfig(wayland-protocols) >= 1.25
BuildRequires:  pkgconfig(wayland-scanner) >= 1.20
BuildRequires:  pkgconfig(x11) >= 1.6.5
%if %{with git}
BuildRequires:  gtk-doc
BuildRequires:  xfce4-dev-tools
%endif

%description
The libxfce4ui library provides a number of widgets commonly used by Xfce
applications.

%package -n libxfce4ui-2-0
Summary:        Widgets Library for the Xfce Desktop Environment
# uses exo-open
License:        GPL-2.0-or-later
Group:          System/Libraries
Requires:       exo-tools
# -branding only contains keyboard shortcuts for some libxfce4ui consumers so
# it is not really a dependency but it must be dragged in at a low level
Recommends:     %{name}-branding = %{version}
Recommends:     %{name}-lang = %{version}

%description -n libxfce4ui-2-0
The libxfce4ui library provides a number of widgets commonly used by Xfce
applications. This package provides the GTK 3 variant of libxfce4ui.

%package -n libxfce4kbd-private-3-0
Summary:        XFCE keyboard library for xfwm
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libxfce4kbd-private-3-0
The libxfce4kbd-private library provides helper functions for xfwm4.

%package tools
Summary:        Tools from libxfce4ui
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE

%description tools
This package provides tools from libxfce4ui.

%package devel
Summary:        Development Files for the libxfce4ui Library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       libxfce4kbd-private-3-0 = %{version}-%{release}
Requires:       libxfce4ui-2-0 = %{version}-%{release}
Recommends:     %{name}-doc = %{version}

%description devel
This package provides development files for developing applications based on
the libxfce4ui library.

%package doc
Summary:        Documentation for the libxfce4ui Library
License:        LGPL-2.1-or-later
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package provides the documentation for the libxfce4ui library.

%package branding-upstream
Summary:        Upstream Branding of libxfce4ui
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
Supplements:    packageand(libxfce4ui-2-0:branding-upstream)
# BRAND: xfce4-keyboard-shortcuts.xml: Controls the global keyboard shortcuts
# BRAND: for the Xfce desktop.
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}
BuildArch:      noarch

%description branding-upstream
This package provides the upstream look and feel for libxfce4ui.









# this should be replaced by %%lang_package once bnc#513786 is resolved

%package lang
Summary:        Languages for package %{name}
License:        LGPL-2.1-or-later
Group:          System/Localization
Requires:       libxfce4ui-2-0 = %{version}
Provides:       %{name}-lang-all = %{version}
Supplements:    packageand(bundle-lang-other:libxfce4ui-2-0)
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%package -n typelib-1_0-Libxfce4ui-2_0
Summary:        UI Library for the Xfce Desktop Environment
License:        LGPL-2.1-or-later
Group:          System/Libraries
Provides:       typelib-1_0-libxfce4ui-2_0 = %{version}
Obsoletes:      typelib-1_0-libxfce4ui-2_0 < %{version}

%description -n typelib-1_0-Libxfce4ui-2_0
The libxfce4ui library provides a number of widgets commonly used by Xfce
applications.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode \
    --enable-startup-notification \
    --with-vendor-info=openSUSE \
    --disable-static \
    --enable-vala=yes \
    --enable-gladeui2
%else
%configure \
    --enable-startup-notification \
    --with-vendor-info=openSUSE \
    --disable-static \
    --enable-vala=yes \
    --enable-gladeui2
%endif
%make_build

%install
%make_install

install -D -p -m 755 %{SOURCE1} %{buildroot}%{_bindir}/xfhelp4

find %{buildroot} -type f -name "*.la" -delete -print

%suse_update_desktop_file xfce4-about -r X-XFCE X-Xfce-Toplevel

# remove unsupported locales
rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{?no_lang_C}

%fdupes %{buildroot}%{_includedir}

%post   -n libxfce4ui-2-0 -p /sbin/ldconfig
%postun -n libxfce4ui-2-0 -p /sbin/ldconfig
%post   -n libxfce4kbd-private-3-0 -p /sbin/ldconfig
%postun -n libxfce4kbd-private-3-0 -p /sbin/ldconfig

%files -n libxfce4ui-2-0
%license COPYING
%{_libdir}/libxfce4ui-2.so.*

%files -n libxfce4kbd-private-3-0
%{_libdir}/libxfce4kbd-private-3.so.*

%files lang -f %{name}.lang

%files devel
%doc AUTHORS NEWS THANKS TODO
%{_libdir}/libxfce4ui-*.so
%{_libdir}/libxfce4kbd-private-*.so
%{_libdir}/pkgconfig/libxfce4ui-*.pc
%{_libdir}/pkgconfig/libxfce4kbd-private-*.pc
%{_libdir}/glade/*
%{_includedir}/xfce4/libxfce4ui-2/
%{_includedir}/xfce4/libxfce4kbd-private-3/
%{_datadir}/vala/vapi/
%{_datadir}/gir-1.0/Libxfce4ui-2.0.gir
%{_datadir}/glade/*

%files tools
%{_bindir}/xfhelp4
%{_bindir}/xfce4-about
%{_datadir}/applications/xfce4-about.desktop
%{_datadir}/icons/hicolor/*/apps/{org.xfce.about.*,xfce4-logo.*}

%files doc
%doc %{_datadir}/gtk-doc/html/libxfce4ui/

%files branding-upstream
%dir %{_sysconfdir}/xdg/xfce4
%dir %{_sysconfdir}/xdg/xfce4/xfconf
%dir %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml
%config %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml/xfce4-keyboard-shortcuts.xml

%files -n typelib-1_0-Libxfce4ui-2_0
%{_libdir}/girepository-1.0/Libxfce4ui-2.0.typelib

%changelog
* Sun Dec 15 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.20.0
  * Update active contributors for 4.20
  * Translation Updates
* Sun Dec  1 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.7 [development release]
  * xfce4-about: Don't show mail addresses
  * xfce4-about: Init glibtop before using it
  * Avoid undefined behavior with NULL msgid strings and dgettext
  * Translation Updates
* Fri Oct 25 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.6 [development release]
  * Add "overlap groups" to the shortcut editor (#115)
  * build: Bump requirements for Xfce 4.20
  * shortcuts: Fix xfconf_channel_get_properties leak
  * Fix AtkRelationSet leak in xfce_gtk_label_set_a11y_relation
  * Apply .clang-format file
  * Add missing includes of libxfce4ui-alias.h
  * clipboard-manager: Add missing include guard
  * Remove forced icon from XfceTitledWindow cliend side decorations
  * clipboard-manager: Use GtkClipboard iff image-only format is
    available
  * xfce4-about: Show info about windowing system
  * dialogs: Also wrap primary label to limit dialog size
  * gcc-analyzer: Fix -Wanalyzer-null-dereference
  * gcc-analyzer: Add false positive file
  * scan-build: Add false positive file
  * build: clang: Fix -Wcast-align
  * Revert "Add new CI builds to build without X11 and Wayland"
  * | is a GNU sed extension; use a portable construct instead
  * clipboard-manager: Get images from GtkClipoard
  * Translation Updates
- Add 0001-relax-x11-version.patch to allow build for Leap with its
  ancient but sufficient X11 packages.
* Tue Apr  2 2024 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.19.5
* Fri Mar  8 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.6
  * shortcuts-grabber: Remove filtering by level
* Mon Feb  5 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.5
  * Update copyright year
  * build: Search for bind_textdomain_codeset in libintl too
  * sm-client: Reset SmcConnection when IceConnection is closed on
    error
  * docs: Improve xfce_sm_client_get()
  * shortcuts-grabber: Fix filtering by level
  * shortcuts-grabber: Simplify filtering by group
  * shortcuts-grabber: Variable renaming
  * shortcuts-grabber: Filter grabbing by key level
  * Detect keyboard shortcuts with only single modifier keys on key
    release
  * Translation Updates
* Mon May 22 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.4
  * Prevent recursive calling of lock command
  * Add lock-on-sleep property
  * Update fallback list
  * Prioritize user lock command
  * Rewrite D-Bus proxies management
  * Use reasonable timeout for methods that may not reply
  * Remove support for gnome-screensaver (Fixes #62)
  * Do not take into account empty commands
  * Simplify Xfconf management
  * Fix memory leak
  * Fix typos
  * Run lock command synchronously (Fixes #70)
  * Add missing include guard
* Tue Mar 28 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.3
  * Add comment about the need for gtk_widget_destroy()
  * Fix memory management in Vala generated code
  * Add annotation "(nullable)" where appropriate
  * Replace deprecated annotation: "(allow-none)"
  * Harden xfce_gtk_handle_tab_accels (thunar#1067)
  * screensaver: Avoid Xfconf warning
  * shortcuts-grabber: Ignore keyboard layout change
  * screensaver: Fix Xfconf memory management
* Thu Feb  9 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.2
  * Update copyright year
  * Add XfceScreensaver (!89)
  * docs: Fix broken links
  * shortcut-dialog: Use parent window for the grab if possible (Fixes #52)
  * Fix memory leaks
* Wed Jan 11 2023 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.18.1
  * Enable line wrapping in the XfceFileNameInput widget
    (gxo#xfce/libxfce4ui#60)
  * xfce4-about: Removed excess square brackets
  * Revert "XfceShortcutsGrabber: Detect auto-repeat key press"
  * Translation Updates
- Removed unused _service file
* Sun Dec 18 2022 Dirk Müller <dmueller@suse.com>
- update to 4.18.0:
  * Bump requirements for Xfce 4.18
  * `g_once_init_enter()` parameter shouldn't be volatile anymore.
  * about: Fix invalid length and Zink renderer string
  * about: Make Close button translateable
  * about: Replace stock with regular button
  * Add 4.18 section to docs
  * Add comment to return gboolean in XfceGtkActionEntry
  * Add functions for handling accelerators that use the Tab key
  * Add new function xfce_gtk_toggle_tool_button_new_from_action_entry
  * Add new method "xfce_gtk_menu_append_separator"
  * Add xfce_gdk_device_grab
  * added xfce_gtk_label_set_a11y_relation to be used by various components
  * Change "Setting System" to "Settings Manager"
  * Check if pixbuf is valid before unref
  * Check time.h and sys/time.h for libgtop
  * Delay whitespace warning in XfceFilenameInput
  * docs: Add missing deprecation guards
  * docs: Add missing documentation
  * docs: Add missing index of deprecated symbols
  * docs: Fix "unused declarations" warning
  * docs: Fix some broken links
  * Don't leak pixbuf
  * Don't reserve vertical space for subtitles in headerbars
  * Fix cast alignment warning
  * Fix intltool lock file problem during make distcheck
  * Fix titled dialog subtitle when headerbar is not used
  * Fix xfce_gdk_screen_get_active to return correct monitor number
  * Function description spelling and format.
  * i18n: Do not use textdomain() in libs
  * initialize base_property prior xfce_shortcuts_provider_register
  * Introduce a shortcuts editor widget
  * libxfce4kbd-private: Reset shortcut recursively
  * Prevent resizing on message display with XfceFilenameInput
  * Remove Gtk2 leftovers
  * Replace duplicate logic with xfce_str_replace
  * Revamp the documentation to uniformize accross components
  * Secure memory allocations
  * Shortcuts Editor: Tooltip improvement
  * shortcuts-grabber: Filter grabbing by key group
  * shortcuts-grabber: Record xkb state group
  * shortcuts-grabber: Redesign shortcut regrabbing
  * shortcuts-grabber: Stop search when the first match is found
  * shortcuts: Add Alt+Super+s for orca
  * shortcuts: Fix a memory leak
  * Simplify startup notification timeout
  * Switch keyboard shortcut 'tile-up' with 'tile-down'
  * tests: Fix deprecation warning
  * titled-dialog: CSD XfceTitledDialog improvements
  * titled-dialog: Exclude normal windows from CSD adjustments
  * Update COPYING
  * Update About credits
  * Usage of '&lt;' and '&gt;' instead of '<' and '>' in XML
  * Use headerbars for dialogs if Gtk/DialogsUseHeader is enabled
  * xfce-about: Add kernel and gtk version to system tab
  * xfce-about: Fix potential NULL pointer access
  * xfce-about: Slightly tweak padding
  * xfce-dialogs: Fix a memory leak
  * xfce-spawn: Do not change DISPLAY on non-X11 displays
  * xfce4-about - improve /etc/os-release value unquoting
  * xfce4-about: Add support for 3A5000/loongarch64
  * XfceShortcutDialog: Do not propagate key events
  * XfceShortcutDialog: Fix a memory leak
  * XfceShortcutsDialog: center the dialog on the parent window
  * XfceShortcutsEditor: Add new vectorized constructor
  * XfceShortcutsEditor: Allow NULL for section name and document it
  * XfceShortcutsEditor: Allow to choose "Space" or "Enter" as shortcut
  * XfceShortcutsEditor: Do not update editor if shortcut change failed
  * XfceShortcutsEditor: Remove label formatting if necessary
  * XfceShortcutsGrabber: Detect auto-repeat key press
  * XfceShortcutsGrabber: Fix `-Wanalyzer-null-dereference` warning
  * XfceTitledDialog: Add pixbuf support as fallback
  * Translation Updates
* Wed May 11 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint report "libxfce4ui-2-0.x86_64: E:
  shlib-policy-name-error SONAME: libxfce4kbd-private-3.so.0,
  expected package suffix: 3-0"
- Move documentation to -devel package
* Tue Sep  7 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.16.1
  * Add 4.16 section to docs
  * about: Replace stock with regular button
  * about: Make Close button translatable (bxo#xfce/libxfce4ui#41)
  * Fix cast alignment warning
  * Remove Gtk2 leftovers
  * Don't reserve vertical space for subtitles in headerbars
  * Translation Updates
- Remove headerbar_subtitle.patch - fixed upstream
* Fri Mar  5 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Build package with glade support
* Thu Dec 24 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Added headerbar_subtitle.patch to remove subtitle space from
  headerbars in Xfce applications
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.16.0
  * about: Harmonize capitalisation
  * Update credits for Xfce 4.16
  * Translation Updates
* Wed Dec 16 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.8
  * Add xfce_has_gtk_frame_extents to better handle CSD
  * Translation Updates
* Mon Dec 14 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.7
  * libxfce4ui now needs libxfce4util >= 4.15.6
  * Update configure.ac.in syntax
  * Namespace of the gir needs capital first letter
  * Remove hardcoded translators list
  * Bump libepoxy version to 1.2
  * Translation Updates
- Rename typelib subpackage to match gir name
* Sun Dec 13 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.6
  * Introduce xfce_spawn and xfce_spawn_command_line
    in favor and instead of xfce_spawn_no_child
  * Bump GLib (and gio, gthread, etc) minimum to 2.50.0
  * about: Support multiple GPUs and print GPU memory size
  * about: Drop window subtitle
  * Always perform sanity check
  * Avoid checking for epoxy if libgtop is disabled
  * XfceTitledDialog: Fix erroneous check (gxo#xfce/libxfce4ui#30)
  * No startup notification in Wayland to prevent crash
    (gxo#xfce/libxfce4ui#17)
  * Translation Updates
* Fri Nov 20 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Fix dependencies and add introspection for vala bindings
* Thu Nov 19 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.5
  * Add new API xfce_spawn_no_child (gxo#xfce/libxfce4ui!8):
    Launch processes re-parenting them to init vs. as children
  * about: Fix icon names
  * about: Display userspace bitness if it differs from OS kernel
    bitness
  * about: Print GPU name in system info
  * about: Use more understandable arch labels
    (gxo#xfce/libxfce4ui#27)
  * Improve xfce_icon_name API
  * No startup notification in wayland to prevent crash
    (gxo#xfce/libxfce4ui#17)
  * Add missing docstring
  * Fix typos
  * Add README.md to EXTRA_DIST
  * Translation Updates
* Tue Nov  3 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.4
  * Avoid redundant key re-grabbing
  * Adds new README.md and updates AM_INIT_AUTOMAKE
  * Silence compiler warnings (gxo#xfce/libxfce4ui#25)
  * AC_CONFIG_MACRO_DIR → AC_CONFIG_MACRO_DIRS
  * Add default shortcuts for tiling (gxo#xfce/libxfce4ui#4)
  * Avoid shortening the keycodes GArray while walking it.
  * about: Revamp About Xfce tab
  * about: More icon name fixes
  * Add more logo icons and new about icon
  * Update deprecated icon names
  * keyboard-shortcuts: Improve UI for setting shortcuts
  * shortcut-dialog: Add label to clear button
  * shortcut-dialog: Port to new XfceTitledDialog API
  * shortcut-dialog: Only grab keyboard
  * Always return GTK_RESPONSE_OK for accepted shortcut keys
    (gxo#xfce/libxfce4ui#20)
  * Translation Updates
* Fri Aug 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.3
  * Update bug URLs to point to gitlab.xfce
  * xfce-about: Hide empty email address tags (gxo#xfce/libxfce4ui#12)
  * Remove translator email address as per request
    (gxo#xfce/libxfce4ui#11)
  * Add missing translator to xfce4-about (gxo#xfce/libxfce4ui#18)
  * Replace deprecated 'gdk_keyboard_ungrab' function
    (gxo#xfce/libxfce4ui#15)
  * shortcuts-grabber: Correctly ungrab keys on updating shortcuts
    (gxo#xfce/libxfce4ui#16)
  * Allow more granular control over menu item accelerators.
  * No automatic accelerator activation formenu items
  * Added 'gtk_menu_item_set_accel_label'
  * Added 'xfce_gtk_accel_group_connect_action_entries'
  * renamed 'xfce_gtk_accel_group_append' to
    'xfce_gtk_accel_map_add_entries' and modified internals accordingly.
  * No automatic add to an accel_group any more, since this may
    lead to double-activation in some cases.
  * Add "xfce_gtk_accel_group_disconnect_action_entries" to be
    able to revert "xfce_gtk_accel_group_connect_action_entries"
  * Add title to xfce_dialog_confirm_close_tabs
  * Add new methods to libxfce4ui.symbols.
  * Introduced 'XfceGtkActionEntry' as replacement for the deprecated
    'GtkAction', 'GtkActionEntry' in order to keep simple menu creation.
    This includes various support methods, like:
  - 'xfce_gtk_translate_action_entries' to to translate a list of
    XfceGtkActionEntrys
  - 'xfce_gtk_accel_group_append' to register the provided accelerators
    of the entries
  - 'xfce_gtk_get_action_entry_by_id' to find a single XfceGtkActionEntry,
    e.g. by using a enumeration
  - 'xfce_gtk_***_new_from_action_entry' to createthe specific menu-
    or tool-items from an XfceGtkActionEntry
  * Add a widget for filename input (bxo#16542)
  * Enabled doc generation for XfceGtkActionEntry and related methods
  * Enabled doc generation for new widget 'xfce-filename-input'
  * Switch Ctrl+Alt+Del to xfce4-session-logout (bxo#11979)
  * Add more default keyboard shortcuts (bxo#16470)
  * shortcuts: Replace xfrun4 by xfce4-appfinder
  * shortcuts: Also map Homepage to browser
  * shortcuts: Remove calculator shortcut
  * Switch XfceTitledDialog to headerbar/CSD layout
  * Use GtkMessageDialog as base class for Xfce Dialogs
  * Add two new functions to search for app icons
  * Improve Tests and Docs
  * Switch XfceTitledDialog to headerbar layout
  * XfceTitledDialog: Keep buttons in the action area
  * XfceTitledDialog: Also repack xfce_titled_dialog_new
  * XfceTitledDialog: Make sure windows can be dragged
  * XfceTitledDialog: Add _create_action_area, _add_button
  * and _add_action_widget
  * Introduce xfce_titled_dialog_set_default_response
  * Mark xfce_titled_dialog_new_with_buttons as deprecated
  * Add two new functions to search for app icons
  * xfce-about: Fix Makefile
  * shortcut-dialog: Show dialog content (bxo#16338)
  * xfce-dialogs: Use GtkMessageDialog as base class
  * xfce-dialogs: Improve layout of confirm_close_tabs
  * xfce-dialogs: Improve alignment and layout of dialogs
  * xfce-dialogs: Add right margin back to labels
  * xfce-dialogs: Drop default window titles
  * docs: Add xfce_dialog_confirm_close_tabs
  * tests: Add xfce_dialog_confirm_close_tabs
  * tests: Improve UI
  * tests: Add icons to dialog buttons
  * tests: Simplify code by using XfceTitledDialog
  * tests: Re-order buttons
  * tests: Fix typo in test-ui.c (bxo#16253)
  * Rename test-ui-gtk3 to test-ui
  * Improve docstrings
  * Drop gladeui Gtk2 from distcheck options
  * Drop unused declaration
  * Fix compiler warnings
  * Remove trailing whitespace
  * Always provides needed files for vala binding in dist tarball
  * Add recents functions to libxfce4ui.symbols
  * Drop xfce-header from pot files
  * Update docstrings
  * Fix license text box too small (bxo#16259)
  * .gitignore: ignore all .o files
  * Make autogen output friendlier
  * Drop support for Gtk2
  * Make glibtop an optional dependency ("About System" tab)
  * about: Add system info tab
  * about: Hide system tab conditionally
  * dialogs: Use symbolic window-close icon
  * Fix Window not visible when grabbing keyboard (bxo#16054)
  * Bump Gtk3 to 3.22 (bxo#15781)
  * Do not use gdk_screen_get_monitor_at_point (bxo#15781)
  * Replace gtk_show_uri (bxo#15781)
  * Replace gdk_display_get_screen (bxo#15781)
  * Replace gdk_keymap_get_default (bxo#15781)
  * Replace deprecated device functions (bxo#15781)
  * Replace gdk_error_trap_* and gdk_flush (bxo#15781)
  * Ignore what is hard to replace (bxo#15781)
  * Add a dialog to confirm closure of multiple tabs (bxo#15873)
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Sun Aug 11 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.14.1
  * No changes, re release because 4.14.0 tarball was broken
- Changes from 4.14.0
  * Do not try to a set button' image if an empty string was used
  * Translation Updates
- Cleaned up spec file
* Sun Jul 28 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.13.7
  * Translations Updates
* Sun Jun 30 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.13.6
  * Update active contributors
  * Translation Updates
* Fri May 17 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.14.5
  * Add PrintScreen as shortcut for xfce4-screenshooter (bxo#14524)
  * Add Ctrl + Alt + t as default shortcut for terminal (bxo#14510)
  * Add xfce_gdk_screen_get_geometry (a replacement for
    gdk_screen_width/gdk_screen_height)
  * Remove useless glade_*dir variables from libxfce4ui-{1,2}.pc
    (bxo#13945)
  * Fix release tarball by adding libxfce4ui-dialog-ui.ui
  * Fixes for gladeui2 detection
  * Install icons when gladeui2 is set (bxo#15207)
  * Fix build error with --disable-gtk2 and having gladeui-1.0 installed
  * Remove styling of emails in about dialog (bxo#14638)
  * Fix compiler error -Wcast-function-type (GCC 8)
  * Use https://docs.xfce.org for help url
  * Fix compilation warnings ""defined" may not be portable"
    & Update xfce4-about (core contributors, contributors, translators)
  * Translation Updates
- Added conditional for source section for when building with
  git master sources.
* Sat Apr 27 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.13.4
  * Fix missing gresource file in release tarball (bxo#13705)
  * Add Vala support (Vidar Haarr)
  * Fix gladeui2 path detection (bxo#13944)
  * Fix make distcheck (bxo#14039)
  * Fix incorrect use of AC_ARG_ENABLE(tests..) (bxo#13703)
  * Use BOOLEAN instead of deprecated BOOL
  * Allows to properly show some characters, such as ampersand (bxo#12715)
  * Translation Updates
- Changes from 4.13.3
  * Fix make distcheck with gladeui2 install path
  * Add an --enable-tests option
  * Remove the filterout from introspection sources
  * Move gresource building out of maintainer mode
  * Fix condition in confirm dialog
  * Add POTFILES.skip to appease gmake distcheck gods on OpenBSD
  * Ship libxfce4ui.gresource.xml in the tarball too
  * Add libxfce4ui-marshal.list to EXTRA_DIST to fix
  - -enable-maintainer-mode on released tarballs
  * Fix build error with --disable-gtk2
  * Translation updates
- Changes from 4.13.2
  * Fix build error with --disable-gtk3 bxo#12648
  * Improve layout of labels in xfce dialogs
  * Set a reasonable default window width to make sure labels wrap
  * Improve vertical alignment of primary and secondary label
  * Bump the default dialog width to 500px
  * Update libxfce4ui documentation
  * Fix make docs compilation warning
  * Fix xfce_dialog_show_help(_with_version) doc
  * Remove Makefile.am space to fix autogen.sh warning
  * Better documentation processing
  * Change xfce_dialog_show_help(_with_version)
  * Default debxoto yes instead of full
  * Remove exo dependancy bxo#13326
  * fix: add libxfce4ui_get_resource to abi check symbols bxo#13326
  * Let autotools find and invoke glib-compile-resources bxo#13326
  * Add support for GOBJECT-INTROSPECTION bxo#13461
  * Add GtkDoc checks
  * Add missing introspection.m4 file
  * fix: make distcheck
  * fix: remove deprecation warnings
  * feat: Switch to Gtk3 default, Gtk2 Optional
  * Rename introspection GIR to 4ui-2.0 to match util
  * Translation updates
- Changes from 4.13.1
  * Better Gtk3.20 compatibility (fix XfceHeading style, drop deprecated call)
  * Translation updates
- Changes from 4.13.0
  * Add xfce_widget_reparent to replace the deprecated gtk_widget_reparent
  * Add xfce_titled_dialog_new_with_mixed_buttons to allow for setting
    icon names, button label text and response id.
  * Add xfce_gtk_menu_popup_until_mapped as a convenience function to fix
    widespread problems with popping up menus (e.g. on keyboard shortcuts)
  * Add dialog UI tests for Gtk2 and Gtk3
  * Fix Glade Gtk3 support
  * Fix a memory leak
- Translation updates
- Clean up spec file and dropped obsolete macros
- Added conditional %%bcond_with git for easier maintanance when using
  git master branch
* Mon Dec 18 2017 crrodriguez@opensuse.org
- Add missing buildrequires on direct build dependencies
  x11,pango,cairo,atk and ice.
* Sat Sep 23 2017 seife+obs@b1-systems.com
- correct licenses of libxfce4ui-1-0 and libxfce4ui-2-0 to GPL2.0+,
  because files libxfce4kbd-private/xfce-shortcuts-xfwm4.{c,h} are
  GPL 2, not LGPL.
* Fri Sep 22 2017 seife+obs@b1-systems.com
- disable gtk-doc build, fails with newer gtk-doc > 1.25
- do not package ChangeLog, NEWS is enough
* Thu Jun  1 2017 zaitor@opensuse.org
- Add conditional for pkgconfig(gladeui-1.0) BuildRequires and
  corresponding subpackage glade3-catalog-libxfce4ui. No longer
  build glade integration for Tumbleweed.
* Sun Mar 15 2015 gber@opensuse.org
- update to version 4.12.1
  - fix glade directory information in .pc file (bxo#11353)
  - add shortcuts for xfwm4 to tile windows to corners (bxo#11652)
  - remove unused 'has_member' variable in xfce4-about (bxo#11654)
  - update .gitignore
  - increase xfce4-about default size
  - improve formatting of translators list
  - update translation contributors in xfce4-about
  - update contributors lists
  - translation updates
* Sun Mar  1 2015 Led <ledest@gmail.com>
- update BuildRequires
* Sun Mar  1 2015 Led <ledest@gmail.com>
- update BuildRequires
* Sat Feb 28 2015 gber@opensuse.org
- update to version 4.12.0
  - bump version
  - translation updates
* Thu Feb 19 2015 gber@opensuse.org
- update to version 4.11.2
  - bump dependencies versions (autotools, Xfce libraries)
  - remove SVN $Id$ tags
  - properly quote AC_LANG_SOURCE
  - fix autoconf m4 directory warning
  - fix IT_PROG_INTLTOOL warning
  - fix build with --enable-debug=full and GTK3 (bxo#11176)
  - add .gitignore
  - fix grabbing shortcuts with <Super> modifier (bxo#10373)
  - avoid double forking when spawning external apps (bxo#9373)
  - don't drop startup notify hint when resetting to defaults
    (bxo#10630)
  - add <Ctrl><Alt>l shortcut for screen locking (xflock4)
    (bxo#10728)
  - fix xfce_dialog_show_help()
* Wed Apr 30 2014 gber@opensuse.org
- update to version 4.11.1
  - add xfce_dialog_show_help_with_version() so applications can
    send their own version number and not the desktop version
  - compile GTK+-3 version of libxfce4ui when possible
  - depend on GTK 2.24 and Glib 2.28
  - only define distclean files in maintainer mode (bxo#8974)
  - don't remove keyboard shortcut when entered twice (bxo#8749)
  - fix keyboard shortcuts with Shift modifier (bxo#8744)
  - fix alt + print being detected as SysReq (bxo#7897)
  - use <Primary> instead of <Control> (bxo#8200)
  - fix keyboard shortcuts with keypad (bxo#4178)
  - autotools updates
  - prefer exo-open for opening the manual pages
  - add error domain for XfceSmClient
  - translation updates
- add subpackage libxfce4ui-2-0 with the GTK3 variant of libxfce4ui
* Mon Oct 15 2012 gber@opensuse.org
- avoid circular dependency between libxfce4ui and exo
* Wed May  9 2012 gber@opensuse.org
- add versioned build dependency
* Mon May  7 2012 gber@opensuse.org
- bring back xfhelp4 since it is still needed until all
  applications have been ported to xfce_dialog_show_help() or an
  alternative mechanism
* Thu May  3 2012 gber@opensuse.org
- fix license of libxfce4ui-tools (bnc#760492)
* Sun Apr 29 2012 gber@opensuse.org
- update to version 4.10.0
  - update contributor credits
  - enable startup notification in xfce4-appfinder shortcuts
  - translation updates
- make libxfce4ui-1-0 depend on exo-tools, it uses exo-open
* Sat Apr 14 2012 gber@opensuse.org
- update to version 4.9.2
  - increase gtk and glib versions
  - bump 4util dependency
  - remove unused function prototype
  - translation updates
* Sun Apr  8 2012 gber@opensuse.org
- update to version 4.9.1
  - open docs.xfce.org when Help in xfce4-about is clicked
  - cache header icons and avoid large icons in XfceTitledDialog
  - restore glade directory information in .pc file
  - update translator credits
  - a lot of improvements in the shortcuts code
  - add Alt + F1 as a shortcut for applications menu
  - remove unused code from the internal header widget
  - add xfce4-about from xfce-utils package
  - use xdt-csource instead of exo-csource, depend on xdt 4.9.0
  - update to new xfce4-appfinder commands
  - fix build against 3.9 Glade
  - add shortcuts for XF86WWW and XF86Mail
  - simplify the xfce_gdk_screen_get_active fucntion
  - add xfce_dialog_show_help function
  - translation updates
- dropped libxfce4ui-fix-shortcut-handling.patch which is not
  applicable any more
- split off -tools subpackage
* Sat Mar 31 2012 gber@opensuse.org
- recommending the branding package is enough
* Sat Mar 24 2012 gber@opensuse.org
- split off libxfce4ui-1-0 subpackage in order to conform to the
  shared library packaging policy
- specfile cleanup
- added libxfce4ui-fix-shortcut-handling.patch which normalizes
  string representation of keyboard shortcuts before comparing them
  in the libxfce4kbd-private shortcut matching code
* Fri Dec 23 2011 gber@opensuse.org
- updated to version 4.8.1
  - fix memory leak
  - translation updates
* Fri Oct 14 2011 gber@opensuse.org
- recommend -doc subpackage
* Sun Jan 30 2011 gber@opensuse.org
- improved summaries/descriptions
* Mon Jan 17 2011 gber@opensuse.org
- update to version 4.8.0
  - bugfixes
- dropped
  libxfce4ui-4.7.6-fix-libxfce4kbd-private-buffer-overflow.patch
  since the problem has been fixed
* Wed Jan  5 2011 gber@opensuse.org
- added -branding-upstream subpackage
* Tue Jan  4 2011 gber@opensuse.org
- added
  libxfce4ui-4.7.6-fix-libxfce4kbd-private-buffer-overflow.patch
  which fixes a buffer overflow in libxfce4kbd-private that was
  causing crashes on first startup
- updated to 4.7.6
  - update default shortcuts for xfce4-display-settings
* Fri Dec 24 2010 gber@opensuse.org
- improved descriptions
- corrected categories
- removed unsupported locales
- show compiler output
* Sun Dec  5 2010 prusnak@opensuse.org
- updated to 4.7.5
  - Also request an interact for save-state-extended.
  - Return a NULL state file is the sm-client is disabled.
  - Fix the save-state signal.
  - Translation updates (pt).
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Mon Nov 22 2010 andrea@opensuse.org
- update to 4.7.4
  * Translations update
  * Make g_critical warning about exit(0) a DBG message
  * Fix typo preventing shortcuts from working with new users
  * Add startup notification support for shortcuts
  * Only save startup-notify if enabled
* Tue Oct  5 2010 vuntz@opensuse.org
- Split glade3 catalog in a glade3-catalog-libxfce4ui subpackage.
  Part of bnc#637694.
* Thu Jul 22 2010 andrea@opensuse.org
- exclude the file xfce4-keyboard-shortcuts.xml because conflits
  with the same provided by libxfcegui4
* Wed Jan 13 2010 prusnak@suse.cz
- updated to 4.7.1
  - New function xfce_spawn_on_screen_with_child_watch().
  - Don't generate enums for XfceSMClientPriority.
  - Build ChangeLog during make dist.
  - Add visibility/alias handing code.
  - Rename configure.in.in to configure.ac.in.
  - Some other small fixes.
  - Translation updates (es, pt_BR, sv, pt, kk, ca, gl, sk, cs, lv, eu,
    zh_CN, ja).
* Fri Nov 13 2009 prusnak@suse.cz
- created package (version 4.7.0)
